@@ -1,5 +1,5 @@
 import argparse
-from csv_divider import csv_divider
+from .csv_divider import csv_divider
 
 
 def main():
