@@ -13,7 +13,7 @@ def divide_chunks(rows: List[str], slice_factor: int) -> Generator:
 def csv_divider(input_file: str, lines: int, output_path: str = None, head_row: bool = True):
     folder_name = os.path.basename(input_file).split(".")[0]
     if output_path is None:
-        head_row = os.path.join(os.path.dirname(input_file), folder_name)
+        output_path = os.path.join(os.path.dirname(input_file), folder_name)
 
     # create output path if not exist
     if not os.path.exists(output_path):
